@@ -35,7 +35,7 @@ Usage::
     query_paginator: QueryPaginator = client.get_paginator("query")
     scan_paginator: ScanPaginator = client.get_paginator("scan")
 """
-from mypy_boto3_dynamodb.client import DynamoDBClient, DynamoDBClient as Client
+from mypy_boto3_dynamodb.client import DynamoDBClient as Client, DynamoDBClient
 from mypy_boto3_dynamodb.paginator import (
     ListBackupsPaginator,
     ListTablesPaginator,
@@ -44,8 +44,8 @@ from mypy_boto3_dynamodb.paginator import (
     ScanPaginator,
 )
 from mypy_boto3_dynamodb.service_resource import (
-    DynamoDBServiceResource as ServiceResource,
     DynamoDBServiceResource,
+    DynamoDBServiceResource as ServiceResource,
 )
 from mypy_boto3_dynamodb.waiter import TableExistsWaiter, TableNotExistsWaiter
 
